| Title: | Global Charcoal Database |
|---|---|
| Description: | Contains the Global Charcoal database data. Data include charcoal series (age, depth, charcoal quantity, associated units and methods) and information on sedimentary sites (localisation, depositional environment, biome, etc.) as well as publications informations. Since 4.0.0 the GCD mirrors the online SQL database at <http://paleofire.org>. |
| Authors: | Global Paleofire Working Group <[email protected]> |
| Maintainer: | Olivier Blarquez <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 4.0.7 |
| Built: | 2026-05-08 05:30:11 UTC |
| Source: | https://github.com/oblarquez/gcd |
The GCD package provides Global Charcoal Database data updated at regular intervals to be used in cunjuction with the paleofire package.
| Package: | GCD |
| Type: | Package |
| Version: | 4.0.0 |
| Date: | 2018-03-01 |
| License: | GPL (>=2) |
Global Paleofire Working Group <paleofire gmail.com>
Power, M., J. Marlon, P. Bartlein, and S. Harrison. 2010. Fire history and the Global Charcoal Database: a new tool for hypothesis testing and data exploration. Palaeogeography, Palaeoclimatology, Palaeoecology 291:52-59.
rm(list=ls()) library(GCD) ## Charcoal data: data(paleofiredata) head(paleofiredata) ## Associated sites informations: data(paleofiresites) head(paleofiresites)rm(list=ls()) library(GCD) ## Charcoal data: data(paleofiredata) head(paleofiredata) ## Associated sites informations: data(paleofiresites) head(paleofiresites)
Basin size
A data frame with 7 observations on the following 5 variables.
a numeric vector
a character vector
a character vector
a character vector
a character vector
data(basin_size) ## maybe str(basin_size) ; plot(basin_size) ...data(basin_size) ## maybe str(basin_size) ; plot(basin_size) ...
Charcoal extractions methods present in the database
A data frame with 13 observations on the following 3 variables.
a factor with levels ACID
CPRO GRAV HNPK HVLQ IMAG NOTK
OPPF OTHE POLS SIEV SIPO THSL
a factor with levels Acidification of sample
using gas chromatography to measure elemental carbon (Verardo etal 1990)
charcoal part Ided as opaque phytoclasts/pyrofusinite in palynofacies
anlaysis Charcoal part. Identified in thin slides (soil
micromorphology) Charcoal particles identified by imaging software
Charcoal separated by heavy liquid preparation Cumulative
probability (95% confidence interval) alluvial soil charcoal
GRAVIMETRIC chemical assay (Winkler method) Hand picked
charcoal from soil samples Not known Other Pollen
slide Sieved Sieved + Pollslide
a numeric vector
data(charcoal_methods) ## maybe str(charcoal_methods) ; plot(charcoal_methods) ...data(charcoal_methods) ## maybe str(charcoal_methods) ; plot(charcoal_methods) ...
Charcoal units used in GCD
A data frame with 169 observations on the following 4 variables.
a factor with levels %125 %DWT
%TOF %WTO 100P 1012 1220 1422
1424 3869 5015 5075 6914 7510
7738 7PRA 8POS ABSC ARCC AREA
ARPG BCCT C004 C010 C01K C040
C100 C120 C125 C140 C150 C180
C250 C65X CARE CCMY CG2M CHCO
CHRX CM10 CMGR CMML COML CP20
CPAR CPRA DC13 FRAG G05I G10I
G250 GCHG GCMY GRG1 GRGR GRPC
GT05 GT10 GT12 GT15 GT18 GT1M
GT24 GT25 GT2X GT30 GT38 GT50
GT53 GT5C LT12 LT13 LT18 LT1M
LT25 LT40 M2GR M2ML MCM3 MM2C
MM2G MMDW MMML MT10 MULT NOTK
ORDI OTHE PCM1 PCMY PHYT PP25
PP51 PP52 PPML PPOL PRAB PROB
PTC0 PTC2 PTC3 PTCT PX25 SQC0
SQCU SQCY SQG1 SQG5 SQL5 TOCA
TOM1 TOM2 TOM3 TOM4 TOM5 TOM6
TOM7 TOM8 TOM9 TOMX TOTA UCMY
V025 V100 V125 V255 V501 X01K
X105 X106 X120 X125 X150 X15G
X160 X180 X18C X20P X250 X25P
X310 X37P X459 X500 X50U X512
X515 X520 X53C X550 X55P X55U
XA1K XARE XARP XARS XC25 XCM3
XCOP XFML XFRG XFRP XFRS XIMG
XPEA XPEE XPIX XRIF
a
factor with levels C0P0 CONC INFL NOTK
OTHE SOIL
a character vector
a numeric vector
data(charcoal_methods) ## maybe str(charcoal_methods) ; plot(charcoal_methods) ...data(charcoal_methods) ## maybe str(charcoal_methods) ; plot(charcoal_methods) ...
Table with the dating information contained in GCD
A data frame with 4872 observations on the following 8 variables.
a numeric vector
a factor with many levels
a numeric vector
a numeric vector
a numeric vector
a numeric vector
a numeric vector
a factor with levels
obtained ~~
data(date) ## maybe str(date) ; plot(date) ...data(date) ## maybe str(date) ; plot(date) ...
Type of dates in date.rda
A data frame with 31 observations on the following 4 variables.
a numeric vector
a character vector
a character vector
a numeric vector
obtained ~~
data(date_type) ## maybe str(date_type) ; plot(date_type) ...data(date_type) ## maybe str(date_type) ; plot(date_type) ...
Depositional contexts
A data frame with 17 observations on the following 4 variables.
a numeric vector
a character vector
a character vector
a numeric vector
data(depo_context) ## maybe str(depo_context) ; plot(depo_context) ...data(depo_context) ## maybe str(depo_context) ; plot(depo_context) ...
Landscape description elements
A data frame with 20 observations on the following 3 variables.
a numeric vector
a character vector
a character vector
data(lands_desc) ## maybe str(lands_desc) ; plot(lands_desc) ...data(lands_desc) ## maybe str(lands_desc) ; plot(lands_desc) ...
Material Dated
A data frame with 23 observations on the following 4 variables.
a numeric vector
a character vector
a character vector
a character vector
obtained ~~
data(mat_dated) ## maybe str(mat_dated) ; plot(mat_dated) ...data(mat_dated) ## maybe str(mat_dated) ; plot(mat_dated) ...
Charcoal series from the Global Charcoal Database
A data frame with 134269 observations on the following 4 variables.
a numeric vector
a numeric vector
a numeric vector
a numeric vector
a factor
with levels ACID CPRO GRAV HNPK HVLQ
IMAG NOTK OREC OTHE POLS SIEV
a factor see paleofiresites for details
a factor with levels C0P0 CONC INFL
NOTK OTHE SOIL
data(paleofiredata) ## maybe str(paleofiredata) ; plot(paleofiredata) ...data(paleofiredata) ## maybe str(paleofiredata) ; plot(paleofiredata) ...
Sites description and features
A data frame with 881 observations on the following 17 variables.
id_sitesites primary key from GCD v4.x.x
id_site_oldsites primary key from GCD v3.x.x, deprecated
pref_unitsa factor, see help("charcoal_units") and data("charcoal_units") for details
site_namea character vector
lata numeric vector
longa numeric vector
elevationa numeric vector of elevations
countrya character vector
continenta factor with levels Africa Antarctica Asia Australia Europe North America South America
ISO3ISO3 code by country
num_datinga numeric vector
min_est_agea numeric vector
max_est_agea numeric vector
num_sampa numeric vector
has_depthfactor indicating presence of depths associated to ages
date_inta numeric vector, interval in years between two dates
qtypea factor, see help("charcoal_units") and data("charcoal_units") for details
water_deptha numeric vector
depo_contexta character vector, see help("depo_contex") and data("depo_contex") for details
id_site_typea character vector, see help("site_type") and data("site_type") for details
id_basin_sizea character vector, see help("basin_size") and data("basin_size") for details
id_lands_desca character vector, see help("lands_desc") and data("lands_desc") for details
l12a numeric vector, Levavasseur et al. 2012
rf99a numeric vector, Ramankutty et al. 1999
gcd_versionmain GCD releases
num_versiona numeric vector: version number 401 meaning 4.0.1
update_datedate of data update in the GCD
l12 levels0= Water 1= Boreal forest 2= Desert vegetation 3= Grassland and dry shrubland 4= Savannas abd dry woodlands 5= Temperate forest6= Tropical forest7= Tundra8= Warm temperate9= Warm desert10= Cold desert
rf99 levels 0= Water 1= Tropical Evergreen
Forest/Woodland2= Tropical Deciduous Forest/Woodland3=
Temperate Broadleaf Evergreen Forest/Woodland4= Temperate
Needleleaf Evergreen Forest/Woodland5= Temperate Deciduous
Forest/Woodland6= Boreal Evergreen Forest/Woodland7=
Boreal Deciduous Forest/Woodland8= Evergreen/Deciduous Mixed
Forest/Woodland9= Savanna10= Grassland/Steppe11= Dense Shrubland12= Open Shrubland13=
Tundra14= Desert15= Polar Desert/Rock/Ice
Ramankutty, N., and J.A. Foley (1999). Estimating historical
changes in global land cover: croplands from 1700 to 1992, Global
Biogeochemical Cycles 13(4), 997-1027.
Levavasseur, G., M. Vrac, D.
M. Roche, and D. Paillard. 2012. Statistical modelling of a new global
potential vegetation distribution. Environmental Research Letters 7:044019.
data(paleofiresites) ## maybe str(paleofiresites) ; plot(paleofiresites) ...data(paleofiresites) ## maybe str(paleofiresites) ; plot(paleofiresites) ...
List of GCD publications with DOI and link.
data("pub")data("pub")
A data frame with 664 observations on the following 4 variables.
id_puba numeric vector
citationa character vector
linkweb adresses
DOIDOI
data(pub) ## maybe str(pub) ; plot(pub) ...data(pub) ## maybe str(pub) ; plot(pub) ...
Type of sites
A data frame with 53 observations on the following 4 variables.
a numeric vector
a character vector
a character vector
a character vector
data(site_type) ## maybe str(site_type) ; plot(site_type) ...data(site_type) ## maybe str(site_type) ; plot(site_type) ...